@@ -5,6 +5,7 @@ from cms.models import Title, Page
 from django.core.cache import cache
 from django.db.models.signals import post_save, pre_delete
 from django.dispatch import receiver
+from django.utils.translation import ugettext_lazy as _
 from taggit_autosuggest.managers import TaggableManager
 
 
@@ -14,18 +15,24 @@ from .utils import get_cache_key
 class PageTags(PageExtension):
     tags = TaggableManager()
 
-    def copy_relations(self, oldinstance):
+    def copy_relations(self, oldinstance, language):
         """ Needed to copy tags when publishing page """
         self.tags.set(*oldinstance.tags.all())
+
+    class Meta:
+        verbose_name = _(u'Page tags (all languages)')
 extension_pool.register(PageTags)
 
 
 class TitleTags(TitleExtension):
     tags = TaggableManager()
 
-    def copy_relations(self, oldinstance):
+    def copy_relations(self, oldinstance, language):
         """ Needed to copy tags when publishing page """
         self.tags.set(*oldinstance.tags.all())
+
+    class Meta:
+        verbose_name = _(u'Page tags (language-dependent)')
 extension_pool.register(TitleTags)
 
 
@@ -56,4 +63,4 @@ def cleanup_titletags(sender, instance, **kwargs):
     key = get_cache_key(None, instance.extended_object.page,
                         instance.extended_object.language,
                         instance.extended_object.page.site_id, True)
-    cache.delete(key)
\ No newline at end of file
+    cache.delete(key)
